@@ -20,67 +20,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <stdio.h>
-#include <unistd.h>
-#include <glib.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <sys/wait.h>
-#include <unistd.h>
-#include <locale.h>
 #include "atk_suite.h"
+#include "atk_test_util.h"
 
-#define DATA_FILE TESTS_DATA_DIR"/test.xml"
-
-pid_t child_pid;
-
-void
-run_app (void)
-{
-  int i=0;
-  child_pid = fork ();
-  if (child_pid == 0) {
-    execlp ("./app-test",
-            "./app-test",
-            "--test-data-file",
-            DATA_FILE,
-            NULL);
-    _exit(EXIT_SUCCESS);
-  }
-}
-
-AtspiAccessible * get_root_obj (void)
-{
-  int i;
-  AtspiAccessible *obj= NULL;
-
-  run_app ();
-
-  /* sleep is needed to wait for forked test application */
-  sleep (1);
-
-  obj = atspi_get_desktop (0);
-  gint child_count = atspi_accessible_get_child_count (obj, NULL);
-  if (child_count < 1) {
-    g_test_message ("Fail, test application not found\n");
-    g_test_fail ();
-    kill (child_pid, SIGTERM);
-    return NULL;
-  }
-
-  for (i=0; i<child_count; i++) {
-    AtspiAccessible *child = atspi_accessible_get_child_at_index (obj,i, NULL);
-    if (!strcmp (atspi_accessible_get_name (child, NULL), "root_object"))
-      return child;
-  }
-  g_test_message ("test object not found\n");
-  g_test_fail ();
-
-  kill (child_pid, SIGTERM);
-  return NULL;
-}
+#define DATA_FILE TESTS_DATA_DIR"/test-accessible.xml"
 
 static void
 teardown_accessible_test (gpointer fixture, gconstpointer user_data)
@@ -91,21 +34,21 @@ teardown_accessible_test (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_name (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   g_assert_cmpstr (atspi_accessible_get_name (obj, NULL), ==, "root_object");
 }
 
 static void
 atk_test_accessible_get_description (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   g_assert_cmpstr (atspi_accessible_get_description (obj, NULL), ==, "Root of the accessible tree" );
 }
 
 static void
 atk_test_accessible_get_child_count (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gint child_c = atspi_accessible_get_child_count (obj, NULL);
   g_assert_cmpint ( 3, ==, child_c );
 }
@@ -113,7 +56,7 @@ atk_test_accessible_get_child_count (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_parent (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL );
   AtspiAccessible *parent = atspi_accessible_get_parent (child, NULL );
   g_assert (parent == obj );
@@ -122,7 +65,7 @@ atk_test_accessible_get_parent (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_child_at_index (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 1, NULL );
   g_assert_cmpstr (atspi_accessible_get_name (child, NULL), ==, "obj2");
 }
@@ -130,7 +73,7 @@ atk_test_accessible_get_child_at_index (gpointer fixture, gconstpointer user_dat
 static void
 atk_test_accessible_get_index_in_parent (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 2, NULL);
   int index = atspi_accessible_get_index_in_parent (child, NULL);
   g_assert_cmpint (index, ==, 2);
@@ -139,7 +82,7 @@ atk_test_accessible_get_index_in_parent (gpointer fixture, gconstpointer user_da
 static void
 atk_test_accessible_get_relation_set_1 (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAccessible *child1 = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (child1, 0, NULL);
   GArray *rel_set = atspi_accessible_get_relation_set (child, NULL);
@@ -149,8 +92,8 @@ atk_test_accessible_get_relation_set_1 (gpointer fixture, gconstpointer user_dat
 static void
 atk_test_accessible_get_relation_set_2 (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *root_object = get_root_obj ();
-  AtspiAccessible *obj2 = atspi_accessible_get_child_at_index (root_object, 1, NULL);
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
+  AtspiAccessible *obj2 = atspi_accessible_get_child_at_index (obj, 1, NULL);
   AtspiAccessible *obj2_1 = atspi_accessible_get_child_at_index (obj2, 0, NULL);
   GArray *rel_set = atspi_accessible_get_relation_set (obj2_1, NULL);
   int i=0;
@@ -166,7 +109,7 @@ atk_test_accessible_get_relation_set_2 (gpointer fixture, gconstpointer user_dat
 static void
 atk_test_accessible_get_role (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiRole root_role = atspi_accessible_get_role (obj, NULL);
   g_assert_cmpint (root_role, ==, ATSPI_ROLE_ACCELERATOR_LABEL);
 }
@@ -174,7 +117,7 @@ atk_test_accessible_get_role (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_role_name (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gchar *root_role_name = atspi_accessible_get_role_name (obj, NULL);
   g_assert_cmpstr (root_role_name, ==, "accelerator label");
 }
@@ -182,7 +125,7 @@ atk_test_accessible_get_role_name (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_localized_role_name (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gchar *root_role_name = atspi_accessible_get_localized_role_name (obj, NULL);
   g_assert_cmpstr (root_role_name, ==, "accelerator label");
 }
@@ -190,7 +133,7 @@ atk_test_accessible_get_localized_role_name (gpointer fixture, gconstpointer use
 static void
 atk_test_accessible_get_state_set (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAccessible *child = atspi_accessible_get_child_at_index (obj, 0, NULL);
   AtspiStateSet *states = atspi_accessible_get_state_set (child);
   GArray *states_arr = atspi_state_set_get_states (states);
@@ -211,13 +154,13 @@ atk_test_accessible_get_state_set (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_attributes (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   GHashTable *attr_hash_tab = atspi_accessible_get_attributes (obj, NULL);
   GHashTableIter iter;
   gpointer key, value;
 
-  gchar *valid_keys[] = { "baz", "quux",  "foo" };
-  gchar *valid_values[] = { "qux", "corge", "bar" };
+  gchar *valid_keys[] = { "atspi" };
+  gchar *valid_values[] = { "test" };
 
   g_hash_table_iter_init (&iter, attr_hash_tab );
   int i = 0;
@@ -231,11 +174,11 @@ atk_test_accessible_get_attributes (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_attributes_as_array (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
-  gchar *valid_attr[] = { "foo:bar", "baz:qux", "quux:corge", NULL };
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
+  gchar *valid_attr[] = { "atspi:test", NULL };
   GArray *attr_arr = atspi_accessible_get_attributes_as_array ( obj, NULL);
   int i = 0;
-  g_assert (attr_arr->len == 3);
+  g_assert (attr_arr->len == (sizeof(valid_attr)/sizeof(gchar *))-1);
   for( i = 0; i < attr_arr->len; ++i) {
     g_assert_cmpstr (valid_attr[i], ==, g_array_index (attr_arr, gchar *, i));
   }
@@ -244,7 +187,7 @@ atk_test_accessible_get_attributes_as_array (gpointer fixture, gconstpointer use
 static void
 atk_test_accessible_get_toolkit_name (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gchar *toolkit_name = atspi_accessible_get_toolkit_name (obj, NULL);
 
   g_assert_cmpstr (toolkit_name, ==, "atspitesting-toolkit");
@@ -253,7 +196,7 @@ atk_test_accessible_get_toolkit_name (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_toolkit_version (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gchar *toolkit_ver = atspi_accessible_get_toolkit_version (obj, NULL);
   /* should be empty string, because no value is setted */
   g_assert_cmpstr (toolkit_ver, ==, "");
@@ -262,7 +205,7 @@ atk_test_accessible_get_toolkit_version (gpointer fixture, gconstpointer user_da
 static void
 atk_test_accessible_get_atspi_version (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gchar *atspi_version = atspi_accessible_get_atspi_version (obj, NULL);
   g_assert_cmpstr (atspi_version, ==, "2.0");
 }
@@ -270,7 +213,7 @@ atk_test_accessible_get_atspi_version (gpointer fixture, gconstpointer user_data
 static void
 atk_test_accessible_get_id (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gint app_id = atspi_accessible_get_id (obj, NULL);
   g_assert_cmpint (app_id, !=, -1);
 }
@@ -278,7 +221,7 @@ atk_test_accessible_get_id (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_application (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAccessible *app = atspi_accessible_get_application (obj, NULL);
   g_assert (app != NULL);
 }
@@ -286,7 +229,7 @@ atk_test_accessible_get_application (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_action_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiAction *iface = atspi_accessible_get_action_iface (obj);
   g_assert (iface == NULL);
 }
@@ -294,7 +237,7 @@ atk_test_accessible_get_action_iface (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_collection_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiCollection *iface = atspi_accessible_get_collection_iface (obj);
   g_assert (iface != NULL);
 }
@@ -302,7 +245,7 @@ atk_test_accessible_get_collection_iface (gpointer fixture, gconstpointer user_d
 static void
 atk_test_accessible_get_component_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiComponent *iface = atspi_accessible_get_component_iface (obj);
   g_assert (iface == NULL);
 }
@@ -310,7 +253,7 @@ atk_test_accessible_get_component_iface (gpointer fixture, gconstpointer user_da
 static void
 atk_test_accessible_get_document_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiDocument *iface = atspi_accessible_get_document_iface (obj);
   g_assert (iface == NULL);
 }
@@ -318,7 +261,7 @@ atk_test_accessible_get_document_iface (gpointer fixture, gconstpointer user_dat
 static void
 atk_test_accessible_get_editable_text_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiEditableText *iface = atspi_accessible_get_editable_text_iface (obj);
   g_assert (iface == NULL);
 }
@@ -326,7 +269,7 @@ atk_test_accessible_get_editable_text_iface (gpointer fixture, gconstpointer use
 static void
 atk_test_accessible_get_hypertext_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiHypertext *iface = atspi_accessible_get_hypertext_iface (obj);
   g_assert (iface == NULL);
 }
@@ -334,7 +277,7 @@ atk_test_accessible_get_hypertext_iface (gpointer fixture, gconstpointer user_da
 static void
 atk_test_accessible_get_image_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiImage *iface = atspi_accessible_get_image_iface (obj);
   g_assert (iface == NULL);
 }
@@ -342,7 +285,7 @@ atk_test_accessible_get_image_iface (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_selection_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiSelection *iface = atspi_accessible_get_selection_iface (obj);
   g_assert (iface == NULL);
 }
@@ -350,7 +293,7 @@ atk_test_accessible_get_selection_iface (gpointer fixture, gconstpointer user_da
 static void
 atk_test_accessible_get_table_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiTable *iface = atspi_accessible_get_table_iface (obj);
   g_assert (iface == NULL);
 }
@@ -358,7 +301,7 @@ atk_test_accessible_get_table_iface (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_text_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiText *iface = atspi_accessible_get_text_iface (obj);
   g_assert (iface == NULL);
 }
@@ -366,7 +309,7 @@ atk_test_accessible_get_text_iface (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_value_iface (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiValue *iface = atspi_accessible_get_value_iface (obj);
   g_assert (iface == NULL);
 }
@@ -374,7 +317,7 @@ atk_test_accessible_get_value_iface (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_interfaces (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   gchar *valid_obj_ifaces[] = { "Accessible", "Collection" };
 
   GArray *ifaces = atspi_accessible_get_interfaces (obj);
@@ -387,7 +330,7 @@ atk_test_accessible_get_interfaces (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_object_locale (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   const gchar *obj_locale = atspi_accessible_get_object_locale (obj, NULL);
   g_assert_cmpstr (obj_locale, ==, setlocale (LC_MESSAGES, NULL));
 }
@@ -395,7 +338,7 @@ atk_test_accessible_get_object_locale (gpointer fixture, gconstpointer user_data
 static void
 atk_test_accessible_set_cache_mask (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   AtspiCache cache_mask = ATSPI_CACHE_ROLE;
   atspi_accessible_set_cache_mask (obj, cache_mask);
   g_assert_cmpint (obj->parent.app->cache, ==, cache_mask);
@@ -413,7 +356,7 @@ atk_test_check_cache_cleared (AtspiAccessible *obj)
 static void
 atk_test_accessible_clear_cache (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   atspi_accessible_clear_cache (obj);
   atk_test_check_cache_cleared (obj);
 }
@@ -421,7 +364,7 @@ atk_test_accessible_clear_cache (gpointer fixture, gconstpointer user_data)
 static void
 atk_test_accessible_get_process_id (gpointer fixture, gconstpointer user_data)
 {
-  AtspiAccessible *obj = get_root_obj ();
+  AtspiAccessible *obj = get_root_obj (DATA_FILE);
   guint proc_id = atspi_accessible_get_process_id (obj, NULL);
   g_assert_cmpint (proc_id, ==, child_pid);
 }
@@ -430,73 +373,73 @@ void
 atk_test_accessible(void )
 {
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accesible_get_name",
-    0, NULL, NULL, atk_test_accessible_get_name, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_name, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_description",
-    0, NULL, NULL, atk_test_accessible_get_description, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_description, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_child_count",
-    0, NULL, NULL, atk_test_accessible_get_child_count, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_child_count, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_parent",
-    0, NULL, NULL, atk_test_accessible_get_parent, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_parent, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_child_at_index",
-    0, NULL, NULL, atk_test_accessible_get_child_at_index, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_child_at_index, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_index_in_parent",
-    0, NULL, NULL, atk_test_accessible_get_index_in_parent, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_index_in_parent, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_relation_set_1",
-    0, NULL, NULL, atk_test_accessible_get_relation_set_1, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_relation_set_1, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_relation_set_2",
-    0, NULL, NULL, atk_test_accessible_get_relation_set_2, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_relation_set_2, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_role",
-    0, NULL, NULL, atk_test_accessible_get_role, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_role, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_role_name",
-    0, NULL, NULL, atk_test_accessible_get_role_name, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_role_name, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_localized_role_name",
-    0, NULL, NULL, atk_test_accessible_get_localized_role_name, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_localized_role_name, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_state_set",
-    0, NULL, NULL, atk_test_accessible_get_state_set, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_state_set, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_attributes",
-    0, NULL, NULL, atk_test_accessible_get_attributes, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_attributes, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_attributes_as_array",
-    0, NULL, NULL, atk_test_accessible_get_attributes_as_array, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_attributes_as_array, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_toolkit_name",
-    0, NULL, NULL, atk_test_accessible_get_toolkit_name, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_toolkit_name, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_toolkit_version",
-    0, NULL, NULL, atk_test_accessible_get_toolkit_version, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_toolkit_version, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_atspi_version",
-    0, NULL, NULL, atk_test_accessible_get_atspi_version, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_atspi_version, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_id",
-    0, NULL, NULL, atk_test_accessible_get_id, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_id, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_application",
-    0, NULL, NULL, atk_test_accessible_get_application, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_application, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_action_iface",
-    0, NULL, NULL, atk_test_accessible_get_action_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_action_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_collection_iface",
-    0, NULL, NULL, atk_test_accessible_get_collection_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_collection_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_component_iface",
-    0, NULL, NULL, atk_test_accessible_get_component_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_component_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_document_iface",
-    0, NULL, NULL, atk_test_accessible_get_document_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_document_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_editable_text_iface",
-    0, NULL, NULL, atk_test_accessible_get_editable_text_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_editable_text_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_hypertext_iface",
-    0, NULL, NULL, atk_test_accessible_get_hypertext_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_hypertext_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_image_iface",
-    0, NULL, NULL, atk_test_accessible_get_image_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_image_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_selection_iface",
-    0, NULL, NULL, atk_test_accessible_get_selection_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_selection_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_table_iface",
-    0, NULL, NULL, atk_test_accessible_get_table_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_table_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_text_iface",
-    0, NULL, NULL, atk_test_accessible_get_text_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_text_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_value_iface",
-    0, NULL, NULL, atk_test_accessible_get_value_iface, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_value_iface, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_interfaces",
-    0, NULL, NULL, atk_test_accessible_get_interfaces, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_interfaces, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_object_locale",
-    0, NULL, NULL, atk_test_accessible_get_object_locale, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_object_locale, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_set_cache_mask",
-    0, NULL, NULL, atk_test_accessible_set_cache_mask, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_set_cache_mask, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_clear_cache",
-    0, NULL, NULL, atk_test_accessible_clear_cache, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_clear_cache, teardown_accessible_test );
   g_test_add_vtable (ATK_TEST_PATH_ACCESSIBLE "/atk_test_accessible_get_process_id",
-    0, NULL, NULL, atk_test_accessible_get_process_id, teardown_accessible_test );
+                     0, NULL, NULL, atk_test_accessible_get_process_id, teardown_accessible_test );
 }
